/*
Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'iframe', 'zh', {
	border: '顯示框架框線',
	noUrl: '請輸入 iframe URL',
	scrolling: '啟用捲軸列',
	title: 'IFrame 屬性',
	toolbar: 'IFrame',
	tabindex: 'Remove from tabindex' // MISSING
} );
